==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbSyncDatabaseInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Database specific information for SQL to Azure SQL DB sync migration task inputs
 * @property id Unique identifier for database
 * @property migrationSetting Migration settings which tune the migration behavior
 * @property name Name of database
 * @property schemaName Schema name to be migrated
 * @property sourceSetting Source settings to tune source endpoint migration behavior
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Target database name
 * @property targetSetting Target settings to tune target endpoint migration behavior
 */
public data class MigrateSqlServerSqlDbSyncDatabaseInputResponse(
    public val id: String? = null,
    public val migrationSetting: Map<String, String>? = null,
    public val name: String? = null,
    public val schemaName: String? = null,
    public val sourceSetting: Map<String, String>? = null,
    public val tableMap: Map<String, String>? = null,
    public val targetDatabaseName: String? = null,
    public val targetSetting: Map<String, String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbSyncDatabaseInputResponse):
            MigrateSqlServerSqlDbSyncDatabaseInputResponse =
            MigrateSqlServerSqlDbSyncDatabaseInputResponse(
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                migrationSetting = javaType.migrationSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                schemaName = javaType.schemaName().map({ args0 -> args0 }).orElse(null),
                sourceSetting = javaType.sourceSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                tableMap = javaType.tableMap().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                targetDatabaseName = javaType.targetDatabaseName().map({ args0 -> args0 }).orElse(null),
                targetSetting = javaType.targetSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbSyncDatabaseInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Database specific information for SQL to Azure SQL DB sync migration task inputs
 * @property id Unique identifier for database
 * @property migrationSetting Migration settings which tune the migration behavior
 * @property name Name of database
 * @property schemaName Schema name to be migrated
 * @property sourceSetting Source settings to tune source endpoint migration behavior
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Target database name
 * @property targetSetting Target settings to tune target endpoint migration behavior
 */
public data class MigrateSqlServerSqlDbSyncDatabaseInputResponse(
    public val id: String? = null,
    public val migrationSetting: Map<String, String>? = null,
    public val name: String? = null,
    public val schemaName: String? = null,
    public val sourceSetting: Map<String, String>? = null,
    public val tableMap: Map<String, String>? = null,
    public val targetDatabaseName: String? = null,
    public val targetSetting: Map<String, String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbSyncDatabaseInputResponse): MigrateSqlServerSqlDbSyncDatabaseInputResponse =
            MigrateSqlServerSqlDbSyncDatabaseInputResponse(
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                migrationSetting = javaType.migrationSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                schemaName = javaType.schemaName().map({ args0 -> args0 }).orElse(null),
                sourceSetting = javaType.sourceSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                tableMap = javaType.tableMap().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                targetDatabaseName = javaType.targetDatabaseName().map({ args0 -> args0 }).orElse(null),
                targetSetting = javaType.targetSetting().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            )
    }
}
